==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/MtlsParamsFluentImpl.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class MtlsParamsFluentImpl<A extends MtlsParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements MtlsParamsFluent<A>{

    private MutualTlsBuilder mtls;

    public MtlsParamsFluentImpl(){
    }
    public MtlsParamsFluentImpl(MtlsParams instance){
            this.withMtls(instance.getMtls()); 
    }

    
/**
 * This method has been deprecated, please use method buildMtls instead.
 * @return The buildable object.
 */
@Deprecated public MutualTls getMtls(){
            return this.mtls!=null?this.mtls.build():null;
    }

    public MutualTls buildMtls(){
            return this.mtls!=null?this.mtls.build():null;
    }

    public A withMtls(MutualTls mtls){
            _visitables.remove(this.mtls);
            if (mtls!=null){ this.mtls= new MutualTlsBuilder(mtls); _visitables.add(this.mtls);} return (A) this;
    }

    public Boolean hasMtls(){
            return this.mtls != null;
    }

    public MtlsParamsFluent.MtlsNested<A> withNewMtls(){
            return new MtlsNestedImpl();
    }

    public MtlsParamsFluent.MtlsNested<A> withNewMtlsLike(MutualTls item){
            return new MtlsNestedImpl(item);
    }

    public MtlsParamsFluent.MtlsNested<A> editMtls(){
            return withNewMtlsLike(getMtls());
    }

    public MtlsParamsFluent.MtlsNested<A> editOrNewMtls(){
            return withNewMtlsLike(getMtls() != null ? getMtls(): new MutualTlsBuilder().build());
    }

    public MtlsParamsFluent.MtlsNested<A> editOrNewMtlsLike(MutualTls item){
            return withNewMtlsLike(getMtls() != null ? getMtls(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            MtlsParamsFluentImpl that = (MtlsParamsFluentImpl) o;
            if (mtls != null ? !mtls.equals(that.mtls) :that.mtls != null) return false;
            return true;
    }


    public class MtlsNestedImpl<N> extends MutualTlsFluentImpl<MtlsParamsFluent.MtlsNested<N>> implements MtlsParamsFluent.MtlsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final MutualTlsBuilder builder;
    
            MtlsNestedImpl(MutualTls item){
                    this.builder = new MutualTlsBuilder(this, item);
            }
            MtlsNestedImpl(){
                    this.builder = new MutualTlsBuilder(this);
            }
    
    public N and(){
            return (N) MtlsParamsFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/MtlsParamsFluentImpl.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class MtlsParamsFluentImpl<A extends MtlsParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements MtlsParamsFluent<A>{

    private MutualTlsBuilder mtls;

    public MtlsParamsFluentImpl(){
    }
    public MtlsParamsFluentImpl(MtlsParams instance){
            this.withMtls(instance.getMtls()); 
    }

    
/**
 * This method has been deprecated, please use method buildMtls instead.
 * @return The buildable object.
 */
@Deprecated public MutualTls getMtls(){
            return this.mtls!=null?this.mtls.build():null;
    }

    public MutualTls buildMtls(){
            return this.mtls!=null?this.mtls.build():null;
    }

    public A withMtls(MutualTls mtls){
            _visitables.get("mtls").remove(this.mtls);
            if (mtls!=null){ this.mtls= new MutualTlsBuilder(mtls); _visitables.get("mtls").add(this.mtls);} return (A) this;
    }

    public Boolean hasMtls(){
            return this.mtls != null;
    }

    public MtlsParamsFluent.MtlsNested<A> withNewMtls(){
            return new MtlsNestedImpl();
    }

    public MtlsParamsFluent.MtlsNested<A> withNewMtlsLike(MutualTls item){
            return new MtlsNestedImpl(item);
    }

    public MtlsParamsFluent.MtlsNested<A> editMtls(){
            return withNewMtlsLike(getMtls());
    }

    public MtlsParamsFluent.MtlsNested<A> editOrNewMtls(){
            return withNewMtlsLike(getMtls() != null ? getMtls(): new MutualTlsBuilder().build());
    }

    public MtlsParamsFluent.MtlsNested<A> editOrNewMtlsLike(MutualTls item){
            return withNewMtlsLike(getMtls() != null ? getMtls(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            MtlsParamsFluentImpl that = (MtlsParamsFluentImpl) o;
            if (mtls != null ? !mtls.equals(that.mtls) :that.mtls != null) return false;
            return true;
    }


    public class MtlsNestedImpl<N> extends MutualTlsFluentImpl<MtlsParamsFluent.MtlsNested<N>> implements MtlsParamsFluent.MtlsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final MutualTlsBuilder builder;
    
            MtlsNestedImpl(MutualTls item){
                    this.builder = new MutualTlsBuilder(this, item);
            }
            MtlsNestedImpl(){
                    this.builder = new MutualTlsBuilder(this);
            }
    
    public N and(){
            return (N) MtlsParamsFluentImpl.this.withMtls(builder.build());
    }
    public N endMtls(){
            return and();
    }

}


}
